@@ -9,6 +9,7 @@
 #define _GLOBAL_H_
 #include <gsl/gsl_rng.h>
 
+#include <err.h>
 #include "config.h"
 
 /**
@@ -62,4 +63,16 @@ enum {
 	F_SHORT = 64
 };
 
+/**
+ * @brief This macro is used to unify the checks for the return value of malloc.
+ *
+ * @param PTR - The pointer getting checked.
+ */
+#define CHECK_MALLOC(PTR)                                                      \
+	do {                                                                       \
+		if (PTR == NULL) {                                                     \
+			err(errno, "Out of memory");                                       \
+		}                                                                      \
+	} while (0);
+
 #endif
